#ifndef _PAGE_COMPONENT_H
#define _PAGE_COMPONENT_H

#include "imgui.h"
#include "PageFont.h"
#include "PageDraw.h"
#include "PageWindow.h"

class PageText: public PageDrawComponent {
private:
	const char* text;
	PageFontType font = NORMAL;
	bool bullet = false;
	ImVec4 color;
	bool colorFlag = false;
	bool multiLine = false;
	bool multiLineReadOnly = true;
public:
	PageText(const char* text) {
		this->text = text;
	}
	void drawComponent(void) {
		PAGE_FONT.pushFont(font);
		if (colorFlag) {
			ImGui::PushStyleColor(ImGuiCol_Text, color);
		}
		if (bullet) {
			ImGui::Bullet();
		}
		if (multiLine) {
			char* textLine = (char*)text;
			ImGui::InputTextMultiline("##source", textLine, strlen(textLine), ImVec2(-1.0f, ImGui::GetTextLineHeight() * 16), ImGuiInputTextFlags_AllowTabInput | (multiLineReadOnly ? ImGuiInputTextFlags_ReadOnly : 0));
		} else {
			ImGui::Text(text);
		}
		if (colorFlag) {
			ImGui::PopStyleColor();
		}
		PAGE_FONT.popFont(font);
	}
	PageText* setFont(PageFontType font) {
		this->font = font;
		return this;
	}
	PageText* setBullet() {
		bullet = true;
		return this;
	}
	PageText* setColor(ImVec4 color) {
		this->color = color;
		colorFlag = true;
		return this;
	}
	PageText* setMultiLine() {
		multiLine = true;
		return this;
	}
};

class PageImage: public PageDrawComponent {
private:
	void* image;
	ImVec2 size = ImVec2(100,100);
	ImColor tintColor = ImColor(255,255,255,255);
	ImColor borderColor = ImColor(255,255,255,128);
public:
	PageImage(void* image) {
		this->image = image;
	}
	void drawComponent(void) {
		ImGui::Image((void *)this->image, this->size, ImVec2(0,0), ImVec2(1,1), this->tintColor , this->borderColor);
	}
	PageImage* setSize(ImVec2 size) {
		this->size = size;
		return this;
	}
	PageImage* setSize(float x, float y) {
		return this->setSize(ImVec2(x,y));
	}
};
class PageLink: public PageDrawComponent {
private:
	const char* text;
	PageFontType font = NORMAL;
	bool clicked = false;
public:
	PageLink(const char* text) {
		this->text = text;
	}
	void drawComponent(void) {
		PAGE_FONT.pushFont(font);
		if (ImGui::Selectable(text, &clicked)) {
			if (PAGE_WINDOW.platformOpenUrl != NULL) {
				PAGE_WINDOW.platformOpenUrl(text);
			}
		}
		//ImGui::SameLine();
		PAGE_FONT.popFont(font);
	}
	PageLink* setFont(PageFontType font) {
		this->font = font;
		return this;
	}
};

#endif
