#include "PageController.h"

PageController::PageController(const char* id, const char* title) {
	this->id = id;
	this->title = title;
	this->buildText(this->getTitle())->setFont(HEADER_MAIN);
}

const char* PageController::getId() {
	return id;
}

const char* PageController::getTitle() {
	return title;
}

void PageController::loadImage(const char* filename) {
	printf("loadImage: %s\n",filename);
	void* imageId = (void*)SOIL_load_OGL_texture(filename, SOIL_LOAD_AUTO, SOIL_CREATE_NEW_ID, SOIL_FLAG_MIPMAPS);
	if(imageId == NULL) {
		printf("Failed to load texture\n");
		return;
	}
	this->images.insert(std::pair<const char*,void*>(filename,imageId));
}

int PageController::getImageCount() {
	return this->images.size();
}

int PageController::getDrawCount() {
	return this->components.size();
}

void PageController::drawLayer() {
	for (auto comp : this->components) {
		comp->drawComponent();
	}
}

void PageController::addComponent(PageDrawComponent* component) {
	this->components.push_back(component);
}

void PageController::setMenu(bool menu) {
	this->menu = menu;
}

bool PageController::getMenu() {
	return this->menu;
}

PageText* PageController::buildText(const char* text) {
	PageText* result = new PageText(text);
	addComponent(result);
	return result;
}

PageLink* PageController::buildLink(const char* url) {
	PageLink* result = new PageLink(url);
	addComponent(result);
	return result;
}

PageImage* PageController::buildImage(void* imageRef) {
	PageImage* result = new PageImage(imageRef);
	addComponent(result);
	return result;
}

PageImage* PageController::buildImage(const char* filename) {
	if (images.find(filename) == images.end()) {
		loadImage(filename);
	}
	return buildImage(images.at(filename));
}
