#include "PageWindow.h"

ImGuiWindowFlags WINDOW_PANE_FLAGS = ImGuiWindowFlags_NoTitleBar|ImGuiWindowFlags_NoResize|ImGuiWindowFlags_NoSavedSettings|ImGuiWindowFlags_NoFocusOnAppearing|ImGuiWindowFlags_NoBringToFrontOnFocus;
ImGuiWindowFlags WINDOW_BACKGROUND_FLAGS = WINDOW_PANE_FLAGS|ImGuiWindowFlags_NoScrollbar|ImGuiWindowFlags_NoInputs;

PageWindow::PageWindow() {
}

void PageWindow::renderMenu() {
	ImGui::SetNextWindowPos(ImVec2(ImGui::GetIO().DisplaySize.x * layoutMarginX, ImGui::GetIO().DisplaySize.y * layoutMarginY), ImGuiSetCond_Always);
	ImGui::SetNextWindowSize(ImVec2((ImGui::GetIO().DisplaySize.x * (1.0f - layoutMarginX)) - (ImGui::GetIO().DisplaySize.x * layoutMarginX), menuHeight), ImGuiSetCond_Always);
	ImGui::Begin("Menu###menu", &menuRender , ImVec2(300, 200), 0.5f, WINDOW_PANE_FLAGS);
	PAGE_FONT.pushFont(HEADER_MAIN);
	bool first = true;
	for (auto page : pages) {
		if (!page.second->getMenu()) {
			continue;
		}
		if (!first) {
			ImGui::SameLine();
		}
		first = false;
		if (ImGui::Button(page.second->getTitle())) {
			this->setPageCurrent(page.second);
		}
	}
	PAGE_FONT.popFont(HEADER_MAIN);
	ImGui::End();
}

void PageWindow::renderPage(void) {
	int preHeight = this->menuHeight;
	if (!menuRender) {
		preHeight = 0;
	}
	int postHeight = this->footerHeight;
	if (!footerRender) {
		postHeight = 0;
	}
	ImGui::SetNextWindowPos(ImVec2(ImGui::GetIO().DisplaySize.x * layoutMarginX, (ImGui::GetIO().DisplaySize.y * layoutMarginY)*2 + preHeight), ImGuiSetCond_Always);
	ImGui::SetNextWindowSize(ImVec2((ImGui::GetIO().DisplaySize.x * (1.0f - layoutMarginX)) - (ImGui::GetIO().DisplaySize.x * layoutMarginX), ImGui::GetIO().DisplaySize.y - preHeight - postHeight - (ImGui::GetIO().DisplaySize.y * layoutMarginY)*4 ), ImGuiSetCond_Always);
	ImGui::Begin("Home###content", &pageRender , ImVec2(300, 200), 0.5f, WINDOW_PANE_FLAGS);

	if (pageCurrent == NULL) {
		ImGui::Text("NULL");
	} else {
		pageCurrent->drawLayer();
	}
	ImGui::End();
}

void PageWindow::renderFooter(void) {
	ImGui::SetNextWindowPos(ImVec2(ImGui::GetIO().DisplaySize.x * layoutMarginX, ImGui::GetIO().DisplaySize.y - footerHeight - (ImGui::GetIO().DisplaySize.y * layoutMarginY)), ImGuiSetCond_Always);
	ImGui::SetNextWindowSize(ImVec2((ImGui::GetIO().DisplaySize.x * (1.0f - layoutMarginX)) - (ImGui::GetIO().DisplaySize.x * layoutMarginX), footerHeight), ImGuiSetCond_Always);
	ImGui::Begin("Footer###footer", &footerRender , ImVec2(300, 200), 0.5f, WINDOW_PANE_FLAGS);
	ImGui::Text("(c)2016 ff");
	ImGui::SameLine();
	ImGui::Text(" -<-- -->- ");
	ImGui::SameLine();
	ImGui::Text("Compiled:");
	ImGui::SameLine();
	ImGui::Text(__DATE__);
	ImGui::SameLine();
	ImGui::Text(__TIME__);
	if (footerRenderFPS) {
		ImGui::SameLine();
		ImGui::Text(" - ");
		ImGui::SameLine();
		ImGui::Text("(%.1f FPS)",ImGui::GetIO().Framerate);
	}
	ImGui::End();
}


void PageWindow::draw() {
	if (footerRender) {
		this->renderFooter();
	}
	if (pageRender) {
		this->renderPage();
	}
	if (menuRender) {
		this->renderMenu();
	}
	for (auto comp : layers) {
		comp->drawLayer();
	}
}

PageDrawLayer* PageWindow::addLayer(PageDrawLayer* layer) {
	layers.push_back(layer);
	return layer;
}

PageController* PageWindow::addPage(PageController* page) {
	pages.insert(std::pair<const char*,PageController*>(page->getId(),page));
	return page;
}

PageController* PageWindow::addPage(const char* id, const char* title) {
	return addPage(new PageController(id,title));
}

PageController* PageWindow::findPage(char* id) {
	for (auto page : pages) {
		if (strcmp (page.first, id) != 0) {
			continue;
		}
		return page.second;
	}
	return NULL;
}

void PageWindow::setPageCurrent(PageController* page) {
	if (page != NULL) {
		this->pageCurrent = page;
	} else {
		this->pageCurrent = this->pageNotFound;
	}
	if (platformPageCb != NULL) {
		platformPageCb(this->pageCurrent->getId());
	}
}

void PageWindow::setPageNotFound(PageController* page) {
	this->pageNotFound = page;
}

PageWindow PAGE_WINDOW;

