#ifndef _PAGE_WINDOW_H
#define _PAGE_WINDOW_H

#include "PageController.h"
#include "PageDraw.h"
#include "PageFont.h"
#include "imgui.h"
#include <stdio.h>
#include <map>
#include <SDL2/SDL.h>
#include <SDL2/SDL_opengl.h>


class PageWindow {
private:
	std::map <const char*, PageController*> pages;
	std::vector<PageDrawLayer*> layers;
	void renderMenu();
	void renderPage();
	void renderFooter();


public:
	SDL_Window *window;
	SDL_GLContext glcontext;
	bool windowRun = true;
	bool windowFullScreen = false;
	bool footerRender = true;
	bool footerRenderFPS = true;
	int footerHeight = 30;
	//bool backgroundRender = true;
	ImVec4 backgroundClearColor = ImColor(8, 54, 127);
	bool menuRender = true;
	int menuHeight = 50;
	bool pageRender = true;
	PageController* pageCurrent;
	PageController* pageNotFound;
	float layoutMarginX = 0.07f;
	float layoutMarginY = 0.01f;
	void (*platformOpenUrl)(char* url) = NULL;
	void (*platformPageCb)(char* pageId) = NULL;


	PageWindow();
	void draw();
	PageDrawLayer* addLayer(PageDrawLayer* layer);
	PageController* addPage(PageController* page);
	PageController* addPage(const char* id, const char* title);
	PageController* findPage(char* id);
	void setPageCurrent(PageController* page);
	void setPageNotFound(PageController* page);

	void printDebug() {
		for (auto page : pages) {
			printf("page: %s comp: %i img: %i\n",page.second->getId(),page.second->getDrawCount(),page.second->getImageCount());
		}
	}
};

extern ImGuiWindowFlags WINDOW_PANE_FLAGS;
extern ImGuiWindowFlags WINDOW_BACKGROUND_FLAGS;

extern PageWindow PAGE_WINDOW;

#endif
